check_config

Function check_config 

pub fn check_config(config: &Config, caps: &Capabilities) -> Result<()>
Verifies that a config is valid using a given set of capabilities.

See the module-level docs for more information.

Errors

This function may return a Error::Other if any part of the config is invalid, including the V4L2 controls.