get_capabilities_from_path

Function get_capabilities_from_path 

pub fn get_capabilities_from_path(device: &Path) -> Result<Formats>
Gets the capabilities of a camera at a certain path.

See the module-level docs for more information.

Errors

This function may return a Error::Io if interaction with the filesystem fails or a Error::Camera if the camera returns an error.